import axios from 'axios'
import qs from 'qs'
import { Message } from 'element-ui'
import router from '../router'

const httpRequest = axios.create({
  // baseURL: process.env.VUE_APP_BASE_API,
  timeout: 60000,
  withCredentials: true,
  headers: {
    'Content-Type': 'application/x-www-form-urlencoded',
    tenant: 'transport'
  }
})

// 请求拦截
httpRequest.interceptors.request.use(
  function(config) {
    // 权限接口单独签名
    // https://gitlab.ezijing.com/root/api-documents/-/blob/master/ezijing_permissions/%E7%AD%BE%E5%90%8D%E9%AA%8C%E8%AF%81.md
    if (/^\/api\/permissions/.test(config.url)) {
      // 默认参数
      const defaultHeaders = {
        timestamp: parseInt(Date.now() / 1000),
        nonce: Math.random()
          .toString(36)
          .slice(-8),
        'secret-id': 'ezijing_4d63be3530c31f04bdec3c1dcf158ceb',
        'secret-key': 'c365340babb2dd2a8160575e2a5bb1b0',
        signature: 'UG7wBenexQhiuD2wpCwuxkU0jqcj006d'
      }
      config.headers = Object.assign(config.headers, defaultHeaders)
    }
    if (config.headers['Content-Type'] === 'application/x-www-form-urlencoded') {
      config.data = qs.stringify(config.data)
    }
    if (config.headers['Content-Type'] === 'multipart/form-data') {
      const form = new window.FormData()
      for (const key in config.data) {
        form.append(key, config.data[key])
      }
      config.data = form
    }
    return config
  },
  function(error) {
    return Promise.reject(error)
  }
)

// 响应拦截
httpRequest.interceptors.response.use(
  function(response) {
    const { data, config } = response
    if (data.msg === '请先登录') {
      window.location.href = `${webConf.others.loginUrl}?rd=${encodeURIComponent(window.location.href)}`
    }
    if (parseInt(data.code) === 1) {
      return Message.error(data.msg)
    }
    if (data.code) {
      if (data.code === 4001) {
        window.location.href = `${webConf.others.loginUrl}?rd=${encodeURIComponent(window.location.href)}`
      }
      // 无权限
      if (/^\/api\/permissions/.test(config.url) && data.code === 403) {
        router.push('/401')
        return Promise.reject(data)
      }
      return data.message ? Message.error(data.message) : Message.error(data.msg)
    }
    return data
  },
  function(error) {
    if (error.response) {
      const { status, message } = error.response.data
      // 未登录
      if (status === 403) {
        window.location.href = `${webConf.others.loginUrl}?rd=${encodeURIComponent(window.location.href)}`
      }
      Message.error(message || error.response.data)
      return Promise.reject(error.response)
    } else {
      Message.error(error)
    }
    return Promise.reject(error)
  }
)

export default httpRequest
